﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Runtime.CompilerServices;
using GalaSoft.MvvmLight.Messaging;
using WpfApp1_hockey.Data;

namespace WpfApp1_hockey.BL
{
    interface IPlayerLogic
    {
        void AddPlayer(IList<Player> list);
        void ModPlayer(Player playerToModify);
        void DelPlayer(IList<Player> list, Player player);
        // IList<Player> GetAllPlayers(); -> homework!
        // Synchronize UI list + DB list -> homework!
    }

    class PlayerLogic : IPlayerLogic
    {
        IEditorService editorService;
        IMessenger messengerService;
        // IMessenger: dependency "2 layers up" ???
        // Not really layer-bound interface/service... 
        // Detailed in the lecture: Aspect-Oriented Programming!!!

        public PlayerLogic(IEditorService service, IMessenger messenger)
        {
            this.editorService = service;
            this.messengerService = messenger;
        }

        public void AddPlayer(IList<Player> list)
        {
            Player newPlayer = new Player();
            if (editorService.EditPlayer(newPlayer) == true)
            {
                list.Add(newPlayer);
                // Call DB operation...
                messengerService.Send("ADD OK", "LogicResult");
            }
            else
            {
                messengerService.Send("ADD CANCEL", "LogicResult");
            }
        }

        public void ModPlayer(Player playerToModify)
        {
            if (playerToModify == null)
            {
                messengerService.Send("EDIT FAILED", "LogicResult");
                return;
            }

            Player clone = new Player();
            clone.CopyFrom(playerToModify);
            if (editorService.EditPlayer(clone) == true)
            {
                playerToModify.CopyFrom(clone);
                // Call DB operation...
                messengerService.Send("EDIT OK", "LogicResult");
            }
            else
            {
                messengerService.Send("EDIT CANCEL", "LogicResult");
            }
        }

        public void DelPlayer(IList<Player> list, Player player)
        {
            if (player != null && list.Remove(player))
            {
                // Call DB operation...
                messengerService.Send("DELETE OK", "LogicResult");
            }
            else
            {
                messengerService.Send("DELETE FAILED", "LogicResult");
            }


        }
    }
}